@@ -30,14 +30,14 @@ import shutil
 import py_compile
 
 try:
-    import sipconfig
+    from sip4_tqt import sipconfig
 except:
     print ("Can't find sipconfig.py (expected in sys.path)")
     print ("Have you built the correct version of sip?")
     sys.exit (-1)
 
 try:
-    import pyqtconfig
+    from python_tqt import pyqtconfig
 except:
     sipconfig.error ("Can't find pyqtconfig.py in sys.path - exiting")
 
@@ -66,8 +66,8 @@ sipcfg            = sipconfig.Configuration()
 pyqtcfg           = pyqtconfig.Configuration ()
 
 # Initialise the globals.
-pykde_version      = 0x031006
-pykde_version_str  = "3.16.6"
+pytde_version      = 0x031006
+pytde_version_str  = "3.16.6"
 kde_version        = None
 kde_version_str    = None
 kde_version_sfx    = None
@@ -81,86 +81,86 @@ pyqt_min_version   = 0x031000
 kde_sip_flags = []
 
 # Command line options.
-opt_pykdemoddir   = sipcfg.default_mod_dir
-opt_pykdesipdir   = sipcfg.default_sip_dir
+opt_pytdemoddir   = sipcfg.default_mod_dir
+opt_pytdesipdir   = sipcfg.default_sip_dir
 opt_debug         = 0
 opt_concat        = None
 opt_split         = 1
 opt_releasegil    = 0
 opt_tracing       = 0
 opt_static        = 0
-opt_kdebasedir    = None
+opt_tdebasedir    = None
 opt_kdelibdir     = None
 opt_kdeincdir     = None
 opt_dep_warnings  = 0
 opt_libdir        = "lib"
 opt_dist_name     = ""
 
-pykde_modules     = ["dcop", "kdecore", "kdefx", "kdeui", "kio", "kresources", "kabc", "kutils", "kfile", "kparts",\
-                     "khtml", "kspell", "kdeprint", "kmdi"] #, "kspell2"]
+pytde_modules     = ["dcop", "tdecore", "tdefx", "tdeui", "tdeio", "tderesources", "tdeabc", "tdeutils", "tdefile", "tdeparts",\
+                     "tdehtml", "tdespell", "tdeprint", "tdemdi"] #, "tdespell2"]
 
-pykde_imports     = {
+pytde_imports     = {
                     "dcop":       ["qt"],
-                    "kdecore":    ["qt", "dcop"],
-#                    "kdesu":      ["qt", "dcop", "kdecore"],
-                    "kdefx":      ["qt", "dcop", "kdecore"],
-                    "kdeui":      ["qt", "qtxml", "dcop", "kdecore", "kdefx"],
-                    "kio":        ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui"],
-                    "kresources": ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio"],
-                    "kabc":       ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio", "kresources"],
-                    "kutils":     ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio"],
-                    "kfile":      ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio"],
-                    "kparts":     ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio"],
-                    "khtml":      ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kutils", "kio", "kparts"],
-                    "kspell":     ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio", "kfile"],
-                    "kdeprint":   ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui"],
-                    "kmdi":       ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui", "kio", "kparts"],
-                    "kspell2":    ["qt", "qtxml", "dcop", "kdecore", "kdefx", "kdeui"]
+                    "tdecore":    ["qt", "dcop"],
+#                    "tdesu":      ["qt", "dcop", "tdecore"],
+                    "tdefx":      ["qt", "dcop", "tdecore"],
+                    "tdeui":      ["qt", "qtxml", "dcop", "tdecore", "tdefx"],
+                    "tdeio":        ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"],
+                    "tderesources": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio"],
+                    "tdeabc":       ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio", "tderesources"],
+                    "tdeutils":     ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio"],
+                    "tdefile":      ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio"],
+                    "tdeparts":     ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio"],
+                    "tdehtml":      ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeutils", "tdeio", "tdeparts"],
+                    "tdespell":     ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio", "tdefile"],
+                    "tdeprint":   ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"],
+                    "tdemdi":       ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeio", "tdeparts"],
+                    "tdespell2":    ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"]
                     }
 
 kde_includes      = {
                     "dcop":       None,
-                    "kdecore":    None,
-#                    "kdesu":      ["kdesu"],
-                    "kdefx":      None,
-                    "kdeui":      None,
-                    "kio":        ["kio"],
-                    "kresources": ["kio", "../kio", "kresources"],
-                    "kabc":       ["kio", "../kio", "kresources", "kabc"],
-                    "kfile":      ["kio", "../kio"],
-                    "kparts":     ["kio", "../kio", "kparts"],
-                    "khtml":      ["kio", "../kio", "kparts", "dom"],
-                    "kspell":     ["kio"],
-                    "kdeprint":   ["kdeprint"],
-                    "kmdi":       ["kmdi", "kio", "../kio", "kparts"],
-                    "kutils":     ["kio", "../kio"] #,
-#                    "kspell2":    None
+                    "tdecore":    None,
+#                    "tdesu":      ["tdesu"],
+                    "tdefx":      None,
+                    "tdeui":      None,
+                    "tdeio":        ["tdeio"],
+                    "tderesources": ["tdeio", "../tdeio", "tderesources"],
+                    "tdeabc":       ["tdeio", "../tdeio", "tderesources", "tdeabc"],
+                    "tdefile":      ["tdeio", "../tdeio"],
+                    "tdeparts":     ["tdeio", "../tdeio", "tdeparts"],
+                    "tdehtml":      ["tdeio", "../tdeio", "tdeparts", "dom"],
+                    "tdespell":     ["tdeio"],
+                    "tdeprint":   ["tdeprint"],
+                    "tdemdi":       ["tdemdi", "tdeio", "../tdeio", "tdeparts"],
+                    "tdeutils":     ["tdeio", "../tdeio"] #,
+#                    "tdespell2":    None
                     }
 
 postProcess       = {
                     "dcop":       None,
-                    "kdecore":    [["-p ", "kdecore", "-o", "appQuit",  "kdecore.py"],
-                                   #["-p ", "kdecore", "-o", "fixQVariant",  "kdecore.sbf"],
-                                   ["-p ", "kdecore", "-o", "fixSignal",  "kdecorepart0.*"]],
-#                    "kdesu":      None,
-                    "kdefx":      None,
-                    "kdeui":      None, #[["-p ", "kdeui", "-o", "shpix",  "sipkdeuiKSharedPixmap.cpp"]],
-                    "kresources": None,
-                    "kabc":       None,
-                    "kio":        None,
-                    "kfile":      None,
-                    "kparts":     None,
-                    "khtml":      None,
-                    "kspell":     None,
-                    "kdeprint":   None,
-                    "kmdi":       None,
-                    "kutils":     None #,
-#                    "kspell2":    None
+                    "tdecore":    [["-p ", "tdecore", "-o", "appQuit",  "tdecore.py"],
+                                   #["-p ", "tdecore", "-o", "fixTQVariant",  "tdecore.sbf"],
+                                   ["-p ", "tdecore", "-o", "fixSignal",  "tdecorepart0.*"]],
+#                    "tdesu":      None,
+                    "tdefx":      None,
+                    "tdeui":      None, #[["-p ", "tdeui", "-o", "shpix",  "siptdeuiTDESharedPixmap.cpp"]],
+                    "tderesources": None,
+                    "tdeabc":       None,
+                    "tdeio":        None,
+                    "tdefile":      None,
+                    "tdeparts":     None,
+                    "tdehtml":      None,
+                    "tdespell":     None,
+                    "tdeprint":   None,
+                    "tdemdi":       None,
+                    "tdeutils":     None #,
+#                    "tdespell2":    None
                     }
 
 opt_startModName  = ""
 opt_startmod      = 0
-opt_endmod        = len (pykde_modules)
+opt_endmod        = len (pytde_modules)
 
 def check_gcc ():
     global opt_concat
@@ -186,7 +186,7 @@ def check_gcc ():
 
 def init_and_check_sanity ():
     """ Do some initialization and check various versions and
-        attributes of sip and PyQt installations
+        attributes of sip and PyTQt installations
     """
 
     check_gcc ()
@@ -201,20 +201,20 @@ def init_and_check_sanity ():
         if minv:
             sipcfg.error("This version of PyKDE requires SIP v%s or later" % sipcfg.version_to_string(minv))
 
-    # Check SIP has Qt support enabled and check version
+    # Check SIP has TQt support enabled and check version
     if pyqtcfg.qt_version == 0:
-        sipconfig.error("SIP has been built with Qt support disabled.")
+        sipconfig.error("SIP has been built with TQt support disabled.")
     if pyqtcfg.qt_version < qt_min_version:
-        sipconfig.error("SIP has been built with an unsupported Qt version (%s)"\
+        sipconfig.error("SIP has been built with an unsupported TQt version (%s)"\
             % sipcfg.version_to_string (sipcfg.qt_version))
 
-    # Check PyQt built with libqt-mt
+    # Check PyTQt built with libtqt-mt
     if pyqtcfg.qt_threaded == 0:
-        sipconfig.error ("PyKDE requires a threaded Qt version (libqt-mt)")
+        sipconfig.error ("PyKDE requires a threaded TQt version (libtqt-mt)")
 
-    # Check PyQt version
+    # Check PyTQt version
     if pyqtcfg.pyqt_version < pyqt_min_version:
-        sipcfg.error("This version of PyKDE requires PyQt v%s or later"\
+        sipcfg.error("This version of PyKDE requires PyTQt v%s or later"\
             % pyqtcfg.version_to_string(pyqtcfg.pyqt_version))
 
     # find the libs, includes, and version info
@@ -230,7 +230,8 @@ def usage(rcode = 2):
     print "where:"
     print "    -h      displays this help message"
     print "    -c      concatenates each module's C/C++ source files [default]"
-    print "    -d dir  where the PyKDE modules will be installed [default %s]" % opt_pykdemoddir
+    print "    -d dir  where the PyKDE modules will be installed [default %s]" % opt_pytdemoddir
+    print "    -e lib  explicitly specify the python library"
     print "    -g      always release the GIL (SIP v3.x behaviour)"
     print "    -i      no concatenation of each module's C/C++ source files"
     print "    -j #    splits the concatenated C++ source files into # pieces [default 1]"
@@ -240,7 +241,7 @@ def usage(rcode = 2):
     print "    -o dir  the directory containing the KDE header files"
     print "    -r      generates code with tracing enabled [default disabled]"
     print "    -u      build with debugging symbols"
-    print "    -v dir  where the PyKDE .sip files will be installed [default %s]" % opt_pykdesipdir
+    print "    -v dir  where the PyKDE .sip files will be installed [default %s]" % opt_pytdesipdir
     print "    -w      turn on KDE deprecated object warnings when compiling [default off]"
     print "    -z file the name of a file containing command line flags"
 
@@ -252,7 +253,7 @@ def inform_user(stage):
     """
     if stage == 0:
         print
-        print "     PyKDE version %s" % pykde_version_str
+        print "     PyKDE version %s" % pytde_version_str
         print "           -------"
         print
         sipconfig.inform ("Python include directory is %s" % sipcfg.py_inc_dir)
@@ -261,16 +262,16 @@ def inform_user(stage):
         sipconfig.inform ("sip version is %s (%s)" % (sipcfg.sip_version_str,
             sipconfig.version_to_string (sipcfg.sip_version)))
         print
-        sipconfig.inform ("Qt directory is %s" % pyqtcfg.qt_dir)
-        sipconfig.inform ("Qt version is %s" % sipconfig.version_to_string (pyqtcfg.qt_version))
+        sipconfig.inform ("TQt directory is %s" % pyqtcfg.qt_dir)
+        sipconfig.inform ("TQt version is %s" % sipconfig.version_to_string (pyqtcfg.qt_version))
         print
-        sipconfig.inform ("PyQt directory is %s" % pyqtcfg.pyqt_sip_dir)
-        sipconfig.inform ("PyQt version is %s (%s)" % (pyqtcfg.pyqt_version_str,
+        sipconfig.inform ("PyTQt directory is %s" % pyqtcfg.pyqt_sip_dir)
+        sipconfig.inform ("PyTQt version is %s (%s)" % (pyqtcfg.pyqt_version_str,
             sipconfig.version_to_string (pyqtcfg.pyqt_version)))
         print
 
     elif stage == 1:
-        sipconfig.inform ("KDE base directory is %s" % opt_kdebasedir)
+        sipconfig.inform ("KDE base directory is %s" % opt_tdebasedir)
         sipconfig.inform ("KDE include directory is %s" % opt_kdeincdir)
         sipconfig.inform ("KDE lib directory is %s" % opt_kdelibdir)
         sipconfig.inform ("lib directory is %s" % opt_libdir)
@@ -279,8 +280,8 @@ def inform_user(stage):
         sipconfig.inform ("KDE version is %s (0x%x)" % (kde_version_str, kde_version))
         print
 
-        sipconfig.inform("PyKDE modules will be installed in %s" % opt_pykdemoddir)
-        sipconfig.inform("PyKDE .sip files will be installed in %s" % opt_pykdesipdir)
+        sipconfig.inform("PyKDE modules will be installed in %s" % opt_pytdemoddir)
+        sipconfig.inform("PyKDE .sip files will be installed in %s" % opt_pytdesipdir)
         print
 
 
@@ -295,22 +296,22 @@ def create_config(module, template):
     sipconfig.inform("Creating %s..." % module)
 
     content = {
-        "pykde_version":        pykde_version,
-        "pykde_version_str":    pykde_version_str,
+        "pytde_version":        pytde_version,
+        "pytde_version_str":    pytde_version_str,
         "kde_version":          kde_version,
         "kde_version_str":      kde_version_str,
         "kde_version_sfx":      kde_version_sfx,
         "kde_version_extra":    kde_version_extra,
-#        "pykde_bin_dir":        opt_pykdebindir,
-        "pykde_mod_dir":        opt_pykdemoddir,
-        "pykde_sip_dir":        opt_pykdesipdir,
-        "pykde_modules":        pykde_modules,
-        "pykde_kde_sip_flags":  kde_sip_flags,
-        "kdebasedir":           opt_kdebasedir,
+#        "pytde_bin_dir":        opt_pytdebindir,
+        "pytde_mod_dir":        opt_pytdemoddir,
+        "pytde_sip_dir":        opt_pytdesipdir,
+        "pytde_modules":        pytde_modules,
+        "pytde_kde_sip_flags":  kde_sip_flags,
+        "tdebasedir":           opt_tdebasedir,
         "kdelibdir":            opt_kdelibdir,
         "libdir":               opt_libdir,
         "kdeincdir":            opt_kdeincdir,
-        "pykde_modules":        pykde_modules,
+        "pytde_modules":        pytde_modules,
         "dist_name":            opt_dist_name
     }
 
@@ -333,13 +334,13 @@ def getKDEVersion (versFile):
     while not ok and l:
         wl = string.split(l)
         if len(wl) == 3 and wl[0] == "#define":
-            if wl[1] == "KDE_VERSION_MAJOR":
+            if wl[1] == "TDE_VERSION_MAJOR":
                 major = string.strip (wl[2])
 
-            if wl[1] == "KDE_VERSION_MINOR":
+            if wl[1] == "TDE_VERSION_MINOR":
                 minor = string.strip (wl[2])
 
-            if wl[1] == "KDE_VERSION_RELEASE":
+            if wl[1] == "TDE_VERSION_RELEASE":
                 micro = string.strip (wl[2])
 
         if major and minor and micro:
@@ -387,31 +388,31 @@ def search (target, searchPath):
     return path
 
 def discoverKDE3 ():
-    global opt_kdeincdir, opt_kdebasedir, opt_kdelibdir, opt_libdir
+    global opt_kdeincdir, opt_tdebasedir, opt_kdelibdir, opt_libdir
 
-    if not opt_kdebasedir:
+    if not opt_tdebasedir:
         kdeSearchPaths = []
         libSearchPaths = []
         incSearchPaths = []
 
         try:
-            kdeSearchPaths.append (os.environ ["KDEDIR"])
+            kdeSearchPaths.append (os.environ ["TDEDIR"])
         except:
             pass
         kdeSearchPaths.append (os.path.join ("/opt", "trinity"))
         kdeSearchPaths.append ("/usr")
 
-        opt_kdebasedir = search (None, kdeSearchPaths)
+        opt_tdebasedir = search (None, kdeSearchPaths)
 
     if not opt_kdelibdir:
-        libSearchPaths = [os.path.join (opt_kdebasedir, "lib"), os.path.join (opt_kdebasedir, "lib64"), os.path.join (opt_kdebasedir, opt_libdir)]
+        libSearchPaths = [os.path.join (opt_tdebasedir, "lib"), os.path.join (opt_tdebasedir, "lib64"), os.path.join (opt_tdebasedir, opt_libdir)]
 #        print opt_libdir
-        opt_kdelibdir  = search ("libkdecore.so", libSearchPaths)
+        opt_kdelibdir  = search ("libtdecore.so", libSearchPaths)
 
     if not opt_kdeincdir:
-        incSearchPaths = [os.path.join (opt_kdebasedir, "include")]
-        incSearchPaths.append (os.path.join (opt_kdebasedir, "include", "kde")) # Red Hat
-        opt_kdeincdir = search ("kapplication.h", incSearchPaths)
+        incSearchPaths = [os.path.join (opt_tdebasedir, "include")]
+        incSearchPaths.append (os.path.join (opt_tdebasedir, "include", "tde")) # Red Hat
+        opt_kdeincdir = search ("tdeapplication.h", incSearchPaths)
 
 def check_kde_installation():
     """Check the KDE installation and get the version number
@@ -421,24 +422,24 @@ def check_kde_installation():
 
     discoverKDE3 ()
 
-    if not opt_kdebasedir:
+    if not opt_tdebasedir:
         sipconfig.error ("Couldn't locate KDE3 base directory")
 
     if not opt_kdeincdir:
-        sipconfig.error ("Couldn't locate KDE3 include directory (%s is KDE base)" % opt_kdebasedir)
+        sipconfig.error ("Couldn't locate KDE3 include directory (%s is KDE base)" % opt_tdebasedir)
 
     if not opt_kdelibdir:
-        sipconfig.error ("Couldn't locate KDE3 lib directory (%s is KDE base)" % opt_kdebasedir)
+        sipconfig.error ("Couldn't locate KDE3 lib directory (%s is KDE base)" % opt_tdebasedir)
 
-    kdeversion_h = os.path.join(opt_kdeincdir, "kdeversion.h")
+    tdeversion_h = os.path.join(opt_kdeincdir, "tdeversion.h")
 
     inform_user (1)
 
-    if not os.access(kdeversion_h, os.F_OK):
-        sipconfig.error("kdeversion.h could not be found in %s." % opt_kdeincdir)
+    if not os.access(tdeversion_h, os.F_OK):
+        sipconfig.error("tdeversion.h could not be found in %s." % opt_kdeincdir)
 
     # Get the KDE version number.
-    getKDEVersion(kdeversion_h)
+    getKDEVersion(tdeversion_h)
 
     inform_user (2)
 
@@ -474,7 +475,7 @@ def create_top_level (mname):
         elif string.find (line, "@mark@") == 0:
             for p in plus:
                 sipout.write (p)
-        elif mname == "kabc" and kde_version < 0x030200 and string.find (line, "kresourcesmod.sip") >= 0:
+        elif mname == "tdeabc" and kde_version < 0x030200 and string.find (line, "tderesourcesmod.sip") >= 0:
             pass
         else:
             sipout.write (line)
@@ -484,14 +485,14 @@ def create_top_level (mname):
     sipin.close ()
     sipout.close ()
 
-    if mname == "khtml":
-        # PyKDE < 3.3.0 doesn't provide kutils (and khtml doesn't need it)
+    if mname == "tdehtml":
+        # PyKDE < 3.3.0 doesn't provide tdeutils (and tdehtml doesn't need it)
         sippath = srcPath(os.path.join ("sip", mname))
         if kde_version < 0x030300:
             sipin   = open (os.path.join (sippath, mname + "mod.sip"))
             sipout  = open (os.path.join (sippath, mname + "mod.sip.new"), "w")
             for line in sipin:
-                if line.find ("kutilsmod.sip") > 0:
+                if line.find ("tdeutilsmod.sip") > 0:
                     continue
                 sipout.write (line)
             sipin.close ()
@@ -499,10 +500,10 @@ def create_top_level (mname):
             os.unlink (os.path.join (sippath, mname + "mod.sip"))
             os.rename (os.path.join (sippath, mname + "mod.sip.new"), os.path.join (sippath, mname + "mod.sip"))
 
-            os.system ("cp %s %s" % (os.path.join (sippath, "khtml_part.sip.323"), os.path.join (sippath, "khtml_part.sip")))
+            os.system ("cp %s %s" % (os.path.join (sippath, "tdehtml_part.sip.323"), os.path.join (sippath, "tdehtml_part.sip")))
 
         else:
-            os.system ("cp %s %s" % (os.path.join (sippath, "khtml_part.sip.330"), os.path.join (sippath, "khtml_part.sip")))
+            os.system ("cp %s %s" % (os.path.join (sippath, "tdehtml_part.sip.330"), os.path.join (sippath, "tdehtml_part.sip")))
 
 
 def check_distribution ():
@@ -557,11 +558,11 @@ def set_sip_flags():
     kde_sip_flags.append(sipconfig.version_to_sip_tag(kde_version, kdetags, "KDE"))
 
 
-def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, extra_define=None, extra_include_dir=None, extra_lflags=None, extra_lib_dir=None, extra_lib=None, opengl=0, sip_flags=None):
+def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, extra_define=None, extra_include_dir=None, extra_lflags=None, extra_lib_dir=None, extra_lib=None, extra_libs=None, opengl=0, sip_flags=None):
     """Generate the code for a module.
 
     mname is the name of the module.
-    imports is the list of PyQt/PyKDE modules that this one %Imports.
+    imports is the list of PyTQt/PyKDE modules that this one %Imports.
     extra_cflags is a string containing additional C compiler flags.
     extra_cxxflags is a string containing additional C++ compiler flags.
     extra_define is a name to add to the list of preprocessor defines.
@@ -599,7 +600,7 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
 
     if opt_concat:
         argv.append("-j")
-        if mname == "kdeui" and opt_split == 1:
+        if mname == "tdeui" and opt_split == 1:
             splits = 2
         else:
             splits = opt_split
@@ -622,13 +623,13 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
     argv.append(srcPath("sip"))
 
     pyqtInclPathSeen = 0
-    for mod in pykde_imports [mname]:
+    for mod in pytde_imports [mname]:
         if string.find (mod, "q") == 0 and not pyqtInclPathSeen:
             argv.append ("-I")
             argv.append (pyqtcfg.pyqt_sip_dir)
             pyqtInclPathSeen = 1
 
-        elif mod == "dcop" or string.find (mod, "k") == 0:
+        elif mod == "dcop" or string.find (mod, "k") == 0 or string.find (mod, "tde") == 0:
             subdir = os.path.join(srcPath("sip"), mod)
             argv.append("-I")
             argv.append(subdir)
@@ -648,15 +649,15 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
     if not os.access(buildfile, os.F_OK):
         sipconfig.error("Unable to create the C++ code.")
 
-    if mname == "kdecore" and not opt_concat:
-        postProcess ["kdecore"][-1][-1] = "kdecorecmodule.*"
+    if mname == "tdecore" and not opt_concat:
+        postProcess ["tdecore"][-1][-1] = "tdecorecmodule.*"
 
     # Compile the Python stub.
     if sipcfg.sip_version < 0x040000:
         sipconfig.inform("Compiling %s.py..." % mname)
         py_compile.compile(os.path.join(mname, mname + ".py"), os.path.join(mname, mname + ".pyc"))
-    elif mname == "kdecore":
-        postProcess ["kdecore"][-1][-1] = "sip" + postProcess ["kdecore"][-1][-1]
+    elif mname == "tdecore":
+        postProcess ["tdecore"][-1][-1] = "sip" + postProcess ["tdecore"][-1][-1]
 
     # needs to be here (not earlier) to catch .py files if any
     if postProcess [mname]:
@@ -670,16 +671,16 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
     installs = []
     if mname == "dcop":
         if has_objdir:
-            installs.append ([[srcPath("extensions/dcopext.py"), srcPath("extensions/dcopexport.py")], opt_pykdemoddir])
+            installs.append ([[srcPath("extensions/dcopext.py"), srcPath("extensions/dcopexport.py")], opt_pytdemoddir])
         else:
-            installs.append ([["../extensions/dcopext.py", "../extensions/dcopexport.py"], opt_pykdemoddir])
+            installs.append ([["../extensions/dcopext.py", "../extensions/dcopexport.py"], opt_pytdemoddir])
             
 
     if sipcfg.sip_version >= 0x040000:
         warnings = 1
     else:
         warnings = 0
-        installs.append([[mname + ".py", mname + ".pyc"], opt_pykdemoddir])
+        installs.append([[mname + ".py", mname + ".pyc"], opt_pytdemoddir])
 
     sipfiles = []
 
@@ -694,13 +695,13 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
                 
 
 
-    installs.append([sipfiles, os.path.join(opt_pykdesipdir, mname)])
+    installs.append([sipfiles, os.path.join(opt_pytdesipdir, mname)])
 
     makefile = sipconfig.SIPModuleMakefile(
         configuration = pyqtcfg,
         build_file = mname + ".sbf",
         dir = mname,
-        install_dir = opt_pykdemoddir,
+        install_dir = opt_pytdemoddir,
         installs = installs,
         qt = 1,
         opengl = opengl,
@@ -749,23 +750,26 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
 
     if extra_lib == "dcop":
         extra_lib = "DCOP"
-    elif extra_lib == "kfile":
-        extra_lib = "kio"
+    elif extra_lib == "tdefile":
+        extra_lib = "tdeio"
         
     makefile.extra_libs.append(extra_lib)
-    if extra_lib == "kdefx":
-        makefile.extra_libs.append ("kdecore")
-    if extra_lib == "kspell":
-        makefile.extra_libs.append ("kdeui")
-    if extra_lib == "kabc" and kde_version >= 0x030200:
-        makefile.extra_libs.append ("kabc_file")
-    if extra_lib == "kparts" and kde_version >= 0x030500:
+    if extra_lib == "tdefx":
+        makefile.extra_libs.append ("tdecore")
+    if extra_lib == "tdespell":
+        makefile.extra_libs.append ("tdeui")
+    if extra_lib == "tdeabc" and kde_version >= 0x030200:
+        makefile.extra_libs.append ("tdeabc_file")
+    if extra_lib == "tdeparts" and kde_version >= 0x030500:
         makefile.extra_lib_dirs.append (os.path.join (opt_kdelibdir, "trinity"))
 
-    if extra_lib == "kdeprint":
+    if extra_lib == "tdeprint":
         makefile.extra_cflags.append ("-fno-rtti")
         makefile.extra_cxxflags.append ("-fno-rtti")
 
+    if extra_libs:
+        makefile.extra_libs.extend(extra_libs)
+
     if sipcfg.sip_version < 0x040000 and imports:
         # Inter-module links.
         for im in imports:
@@ -779,14 +783,14 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
 def create_makefiles():
     """Create the additional Makefiles.
     """
-    subdirs = pykde_modules[:]
+    subdirs = pytde_modules[:]
 
     sipconfig.inform("Creating top level Makefile...")
 
     sipconfig.ParentMakefile(
         configuration = pyqtcfg,
         subdirs = subdirs,
-        installs= [("pykdeconfig.py", opt_pykdemoddir), (srcPath("contrib/kdepyuic"), opt_kdebasedir + "/bin")]
+        installs= [("pytdeconfig.py", opt_pytdemoddir), (srcPath("contrib/tdepyuic"), opt_tdebasedir + "/bin")]
     ).generate()
 
 
@@ -819,17 +823,20 @@ def main(argv):
     argv is the list of command line arguments.
     """
     try:
-        optlist, args = getopt.getopt(argv[1:], "hcd:gij:k:L:l:n:o:ruv:wz:")
+        optlist, args = getopt.getopt(argv[1:], "hcd:e:gij:k:L:l:n:o:ruv:wz:")
     except getopt.GetoptError:
         usage()
 
-    global opt_pykdemoddir, opt_pykdesipdir
+    global opt_pytdemoddir, opt_pytdesipdir
     global opt_debug, opt_concat, opt_releasegil
     global opt_split, opt_tracing, opt_startModName
     global opt_startmod, opt_endmod
-    global opt_kdebasedir, opt_kdelibdir, opt_kdeincdir, opt_libdir
-    global pykde_modules, opt_dep_warnings, opt_dist_name
-    global pykde_imports, kde_includes
+    global opt_tdebasedir, opt_kdelibdir, opt_kdeincdir, opt_libdir
+    global pytde_modules, opt_dep_warnings, opt_dist_name
+    global pytde_imports, kde_includes
+    global opt_libpython
+
+    opt_libpython = None
 
     # Look for '-z' first and process that switch
     # (command line switches override file switches)
@@ -846,12 +853,15 @@ def main(argv):
         if opt == "-h":
             usage(0)
 
+        elif opt == "-e":
+            opt_libpython = arg
+
         # turns on concatentation (on by default, here for consistency)
         elif opt == "-c":
             opt_concat = 1
 
         elif opt == "-d":
-            opt_pykdemoddir = arg
+            opt_pytdemoddir = arg
         elif opt == "-g":
             opt_releasegil = 1
 
@@ -866,7 +876,7 @@ def main(argv):
                 usage()
 
         elif opt == "-k":
-            opt_kdebasedir = arg
+            opt_tdebasedir = arg
 
         elif opt == "-L":
             opt_libdir = arg
@@ -885,7 +895,7 @@ def main(argv):
         elif opt == "-u":
             opt_debug = 1
         elif opt == "-v":
-            opt_pykdesipdir = arg
+            opt_pytdesipdir = arg
         elif opt == "-w":
             opt_dep_warnings = 1
 
@@ -894,42 +904,45 @@ def main(argv):
 
     # Set the SIP platform, version and feature flags.
     if kde_version < 0x030200:
-        pykde_modules.remove ("kmdi")
-        pykde_modules.remove ("kresources")
-        pykde_imports ["kabc"].remove ("kresources")
-        kde_includes ["kabc"].remove ("kresources")
+        pytde_modules.remove ("tdemdi")
+        pytde_modules.remove ("tderesources")
+        pytde_imports ["tdeabc"].remove ("tderesources")
+        kde_includes ["tdeabc"].remove ("tderesources")
 
     if kde_version < 0x030300:
-        pykde_modules.remove ("kutils")
-#        pykde_modules.remove ("kspell2")
-        pykde_imports ["khtml"].remove ("kutils")
+        pytde_modules.remove ("tdeutils")
+#        pytde_modules.remove ("tdespell2")
+        pytde_imports ["tdehtml"].remove ("tdeutils")
 
-    opt_endmod = len (pykde_modules)
+    opt_endmod = len (pytde_modules)
     if opt_startModName != "":
-        if opt_startModName in pykde_modules:
+        if opt_startModName in pytde_modules:
             single = opt_startModName [-1] != ":"
             if not single:
                 opt_startModName = opt_startModName [:-1]
 
             try:
-                opt_startmod = pykde_modules.index (opt_startModName)
+                opt_startmod = pytde_modules.index (opt_startModName)
                 if single:
                     opt_endmod = opt_startmod + 1
             except:
                 sipconfig.error ("%s is not a PyKDE module" % opt_startModName)
 
-    print "PyKDE modules to be built:\n   %s\n" % string.join(pykde_modules [opt_startmod:opt_endmod])
+    print "PyKDE modules to be built:\n   %s\n" % string.join(pytde_modules [opt_startmod:opt_endmod])
 
     set_sip_flags()
 
-    for module in pykde_modules [opt_startmod:opt_endmod]:
-        generate_code (module, pykde_imports [module], extra_lib = module)
+    for module in pytde_modules [opt_startmod:opt_endmod]:
+        extra_libs = []
+        if opt_libpython:
+            extra_libs.append(opt_libpython)
+        generate_code (module, pytde_imports [module], extra_lib = module, extra_libs = extra_libs)
 
     # Create the additional Makefiles.
     create_makefiles()
 
     # Install the configuration module.
-    create_config("pykdeconfig.py", srcPath("pykdeconfig.py.in"))
+    create_config("pytdeconfig.py", srcPath("pytdeconfig.py.in"))
 
 
 def reporting_msg ():
@@ -938,7 +951,7 @@ If reporting errors, paste all of the output above into your
 message and post to the PyKDE mailing list at:
 
      mailto:    PyKDE@mats.imk.fraunhofer.de
-     subscribe: http://mats.imk.fraunhofer.de/mailman/listinfo/pykde
+     subscribe: http://mats.imk.fraunhofer.de/mailman/listinfo/pytde
 
 You can redirect the output into a file (> output.txt) if needed
 """
